/* Special definitions for GNU plotutils, processed by autoheader.
   Copyright (C) 1997 Free Software Foundation, Inc.
   Robert S. Maier <rsm@math.arizona.edu>, 1997.
*/

/* Define to be the name of the distribution. */
#undef PACKAGE

/* Define to be the version of the distribution.  */
#undef VERSION

/* Define to signal compiler support for void and void * types */
#define HAVE_VOID 1

/* Define under HP/UX to get matherr-related things from math.h. */
#undef _HPUX_SOURCE

/* Define to signal that fflush(NULL) works: it flushes all outstreams. */
#undef HAVE_NULL_FLUSH

/* Redundant and unused: Define to signal that fflush(NULL) doesn't work. */
#undef DONT_HAVE_NULL_FLUSH

/* Define to signal that Motif should be used, if X11 is used */
#undef USE_MOTIF

/* Define to signal support in -lXext for the DBE X11 protocol extension */
#undef HAVE_DBE_SUPPORT

/* Define to signal support in -lXext for the MBX X11 protocol extension */
#undef HAVE_MBX_SUPPORT

/* Define to enable support for the 45 LaserJet fonts in X output */
#undef USE_LJ_FONTS_IN_X

/* Define to enable support for the 45 LaserJet fonts in PS output */
#undef USE_LJ_FONTS_IN_PS

/* Define to enable support for the 35 PS fonts in PCL output */
#undef USE_PS_FONTS_IN_PCL

